@@ -12,7 +12,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-__version__ = "1.0.0"
+__version__ = "1.1.0"
 
 from extras.plugins import PluginConfig
 
@@ -27,14 +27,17 @@ class OnboardingConfig(PluginConfig):
     description = "A plugin for NetBox to easily onboard new devices."
     base_url = "onboarding"
     required_settings = []
+    min_version = "2.8.1"
     default_settings = {
         "create_platform_if_missing": True,
         "create_manufacturer_if_missing": True,
         "create_device_type_if_missing": True,
         "create_device_role_if_missing": True,
         "default_device_role": "network",
+        "default_device_role_color": "FF0000",
         "default_management_interface": "PLACEHOLDER",
         "default_management_prefix_length": 0,
+        "default_device_status": "active",
     }
     caching_config = {}
 
