@@ -19,19 +19,21 @@ menu_items = (
     PluginMenuItem(
         link="plugins:netbox_onboarding:onboarding_task_list",
         link_text="Onboarding Tasks",
-        permissions=[],
+        permissions=["netbox_onboarding.view_onboardingtask"],
         buttons=(
             PluginMenuButton(
                 link="plugins:netbox_onboarding:onboarding_task_add",
                 title="Onboard",
                 icon_class="fa fa-plus",
                 color=ButtonColorChoices.GREEN,
+                permissions=["netbox_onboarding.add_onboardingtask"],
             ),
             PluginMenuButton(
                 link="plugins:netbox_onboarding:onboarding_task_import",
                 title="Bulk Onboard",
                 icon_class="fa fa-download",
                 color=ButtonColorChoices.BLUE,
+                permissions=["netbox_onboarding.add_onboardingtask"],
             ),
         ),
     ),
