@@ -20,6 +20,7 @@ from napalm import get_network_driver
 from napalm.base.exceptions import ConnectionException, CommandErrorException
 
 from django.conf import settings
+from django.utils.text import slugify
 
 from netmiko.ssh_autodetect import SSHDetect
 from netmiko.ssh_exception import NetMikoAuthenticationException
@@ -336,14 +337,14 @@ class NetboxKeeper:
         # instance.
 
         try:
-            self.manufacturer = Manufacturer.objects.get(slug=self.netdev.vendor.lower())
+            self.manufacturer = Manufacturer.objects.get(slug=slugify(self.netdev.vendor))
         except Manufacturer.DoesNotExist:
             if not create_manufacturer:
                 raise OnboardException(
                     reason="fail-config", message=f"ERROR manufacturer not found: {self.netdev.vendor}"
                 )
 
-            self.manufacturer = Manufacturer.objects.create(name=self.netdev.vendor, slug=self.netdev.vendor.lower())
+            self.manufacturer = Manufacturer.objects.create(name=self.netdev.vendor, slug=slugify(self.netdev.vendor))
             self.manufacturer.save()
 
         # Now see if the device type (slug) already exists,
@@ -357,7 +358,7 @@ class NetboxKeeper:
             logging.warning("device model is now: %s", self.netdev.model)
 
         try:
-            self.device_type = DeviceType.objects.get(slug=self.netdev.model.lower())
+            self.device_type = DeviceType.objects.get(slug=slugify(self.netdev.model))
             self.netdev.ot.device_type = self.device_type.slug
             self.netdev.ot.save()
         except DeviceType.DoesNotExist:
@@ -368,7 +369,7 @@ class NetboxKeeper:
 
             logging.info("CREATE: device-type: %s", self.netdev.model)
             self.device_type = DeviceType.objects.create(
-                slug=self.netdev.model.lower(), model=self.netdev.model.upper(), manufacturer=self.manufacturer
+                slug=slugify(self.netdev.model), model=self.netdev.model.upper(), manufacturer=self.manufacturer
             )
             self.device_type.save()
             self.netdev.ot.device_type = self.device_type.slug
@@ -385,12 +386,14 @@ class NetboxKeeper:
         self,
         create_device_role=PLUGIN_SETTINGS["create_device_role_if_missing"],
         default_device_role=PLUGIN_SETTINGS["default_device_role"],
+        default_device_role_color=PLUGIN_SETTINGS["default_device_role_color"],
     ):
         """Ensure that the device role is defined / exist in NetBox or create it if it doesn't exist.
 
         Args:
           create_device_role (bool) :Flag to indicate if we need to create the device_role, if not already present
           default_device_role (str): Default value for the device_role, if we need to create it
+          default_device_role_color (str): Default color to assign to the device_role, if we need to create it
         Raises:
           OnboardException('fail-config'):
             When the device role value does not exist
@@ -400,31 +403,43 @@ class NetboxKeeper:
             return
 
         try:
-            device_role = DeviceRole.objects.get(slug=default_device_role)
+            device_role = DeviceRole.objects.get(slug=slugify(default_device_role))
         except DeviceRole.DoesNotExist:
             if not create_device_role:
                 raise OnboardException(
                     reason="fail-config", message=f"ERROR device role not found: {default_device_role}"
                 )
 
-            device_role = DeviceRole.objects.create(name=default_device_role, slug=default_device_role)
+            device_role = DeviceRole.objects.create(
+                name=default_device_role,
+                slug=slugify(default_device_role),
+                color=default_device_role_color,
+                vm_role=False,
+            )
             device_role.save()
 
         self.netdev.ot.role = device_role
         self.netdev.ot.save()
         return
 
-    def ensure_device_instance(self):
-        """Ensure that the device instance exists in NetBox and is assigned the provided device role or DEFAULT_ROLE."""
-        # TODO: this can create duplicate entries in NetBox...
-        device, _ = Device.objects.get_or_create(
-            name=self.netdev.hostname,
-            device_type=self.device_type,
-            device_role=self.netdev.ot.role,
-            platform=self.netdev.ot.platform,
-            site=self.netdev.ot.site,
-        )
+    def ensure_device_instance(self, default_status=PLUGIN_SETTINGS["default_device_status"]):
+        """Ensure that the device instance exists in NetBox and is assigned the provided device role or DEFAULT_ROLE.
 
+        Args:
+          default_status (str) : status assigned to a new device by default.
+        """
+        try:
+            device = Device.objects.get(name=self.netdev.hostname, site=self.netdev.ot.site)
+        except Device.DoesNotExist:
+            device = Device.objects.create(
+                name=self.netdev.hostname,
+                site=self.netdev.ot.site,
+                device_type=self.device_type,
+                device_role=self.netdev.ot.role,
+                status=default_status,
+            )
+
+        device.platform = self.netdev.ot.platform
         device.serial = self.netdev.serial_number
         device.save()
 
