@@ -13,10 +13,16 @@ limitations under the License.
 """
 from django.urls import path
 
-from .views import OnboardingTaskListView, OnboardingTaskCreateView, OnboardingTaskFeedBulkImportView
+from .views import (
+    OnboardingTaskListView,
+    OnboardingTaskCreateView,
+    OnboardingTaskBulkDeleteView,
+    OnboardingTaskFeedBulkImportView,
+)
 
 urlpatterns = [
     path("", OnboardingTaskListView.as_view(), name="onboarding_task_list"),
     path("add/", OnboardingTaskCreateView.as_view(), name="onboarding_task_add"),
+    path("delete/", OnboardingTaskBulkDeleteView.as_view(), name="onboarding_task_bulk_delete"),
     path("import/", OnboardingTaskFeedBulkImportView.as_view(), name="onboarding_task_import"),
 ]
